'\" t
.tr \(ts"
.ds S \s-1SGML\s0
.de TS
.br
.sp .5
..
.de TE
.br
.sp .5
..
.de TQ
.br
.ns
.TP \\$1
..
.TH NSGMLS 1
.SH NAME
nsgmls \- a validating SGML parser
.sp
An \*S System Conforming to
.if n .br
International Standard ISO 8879 \(em
.br
Standard Generalized Markup Language
.SH SYNOPSIS
.B nsgmls
[
.B \-deglprsuvx
]
[
.BI \-a linktype
]
[
.BI \-f file
]
[
.BI \-i name
]
[
.BI \-m file
]
[
.BI \-t file
]
[
.BI \-w warning_type
]
[
.I filename\|.\|.\|.
]
.SH DESCRIPTION
.I Nsgmls
parses and validates
the \*S document entity in
.I filename\|.\|.\|.
and prints on the standard output a simple text representation of its
Element Structure Information Set.
(This is the information set which a structure-controlled
conforming \*S application should act upon.)
Note that the document entity may be spread amongst several files;
for example, the SGML declaration, document type declaration and document
instance set could each be in a separate file.
If no filenames are specified, then
.I nsgmls
will read the document entity from the standard input.
Each filename is actually interpreted as a system identifier.
A command line filename of
.B \-
can be used to refer to the standard input.
(Normally in a system identifier,
.B fd:0
is used to refer to standard input.)
.LP
The following options are available:
.TP
.BI \-a linktype
Make link type
.I linktype
active.
Not all ESIS information is output in this case:
the active LPDs are not explicitly reported,
although each link attribute is qualified with
its link type name;
there is no information about result elements;
when there are multiple link rules applicable to the
current element,
.I nsgmls
always chooses the first.
.TP
.B \-d
Warn about duplicate entity declarations.
.TP
.B \-e
Describe open entities in error messages.
Error messages always include the position of the most recently
opened external entity.
.TP
.BI \-f file
Redirect errors to
.IR file .
This is useful mainly with shells that do not support redirection
of stderr.
.TP
.B \-g
Show the \s-1GI\s0s of open elements in error messages.
.TP
.BI \-i name
Pretend that
.RS
.IP
.BI <!ENTITY\ %\  name\  \(tsINCLUDE\(ts>
.LP
occurs at the start of the document type declaration subset
in the \*S document entity.
Since repeated definitions of an entity are ignored,
this definition will take precedence over any other definitions
of this entity in the document type declaration.
Multiple
.B \-i
options are allowed.
If the \*S declaration replaces the reserved name
.B INCLUDE
then the new reserved name will be the replacement text of the entity.
Typically the document type declaration will contain
.IP
.BI <!ENTITY\ %\  name\  \(tsIGNORE\(ts>
.LP
and will use
.BI % name ;
in the status keyword specification of a marked section declaration.
In this case the effect of the option will be to cause the marked
section not to be ignored.
.RE
.TP
.B \-l
Output
.B L
commands giving the current line number and filename.
.TP
.BI \-m file
Map public identifiers and entity names to system identifiers
using the catalog entry file whose system identifier is
.IR file .
Multiple
.B \-m
options are allowed.
Catalog entry files specified with the
.B -m
option will be searched before the defaults.
.TP
.B \-p
Parse only the prolog.
.I Nsgmls
will exit after parsing the document type declaration.
Implies
.BR \-s .
.TP
.B \-r
Warn about defaulted references.
.TP
.B \-s
Suppress output.
Error messages will still be printed.
.TP
.BI \-t file
Output to
.I file
the RAST result as defined by
ISO/IEC 13673:1995 (actually this isn't quite an IS yet;
this implements the Intermediate Editor's Draft of 1994/08/29,
with changes to implement ISO/IEC JTC1/SC18/WG8 N1777).
The normal output is not produced.
.TP
.B \-u
Warn about undefined elements: elements used in the DTD but not defined.
.TP
.B \-v
Print the version number.
.TP
.BI \-w warning_type
Give warnings according to the value of
.IR warning_type :
.RS
.TP
.B mixed
Warn about mixed content models that do not allow #pcdata anywhere.
.TP
.B sgmldecl
Warn about various dubious constructions in the SGML declaration.
.TP
.B should
Warn about various recommendations made in ISO 8879 that the document
does not comply with.
(Recommendations are expressed with ``should'', as distinct from
requirements which are usually expressed with ``shall''.)
.TP
.B default
Warn about defaulted references.
(Same as
.BR \-r .)
.TP
.B duplicate
Warn about duplicate entity declarations.
(Same as
.BR \-d .)
.TP
.B undefined
Warn about undefined elements: elements used in the DTD but not defined.
(Same as
.BR \-u .)
.TP
.B all
Give all available warnings.
.LP
Multiple
.B \-w
options are allowed.
.RE
.TP
.B \-x
Suppress check that for each ID reference value there is an element
with that ID.
.TP
.B \-X
If the
.B \-t
option is being used,
do not give an error when a character that is not a significant
character in the reference concrete syntax occurs in a literal in the
SGML declaration.  This may be useful in conjunction with certain
buggy test suites.
.SS "External entities"
An external entity resides in one or more storage objects,
each of which contains a sequence of bytes.
The entity manager component of
.I nsgmls
maps a sequence of storage objects into an entity as follows:
.IP 1.
The bytes in each storage object are converted into characters,
each represented by a single bit combination,
according to the encoding translation associated with the storage object.
.IP 2.
The characters in each storage object are concatenated.
.IP 3.
The sequence of characters is treated as a sequence of lines each
terminated by a line terminator.  The line terminator is
either a line feed or a carriage return or a a carriage return
followed by a line feed.
.I Nsgmls
determines which line terminator to use for a storage object according
to which of the possible line terminators is used for the first line
of the storage object.  A record start is inserted at the beginning of
each line, and a record end at the end of each line.  If there is a
partial line (a line that doesn't end with the line terminator)
at the end of the entity, then a record start will be inserted before it
but no record end will be inserted after it.
.LP
An encoding translation defines a translation between the storage
coding system and the entity coding system.  The storage coding system
represents characters by sequences of bytes; it can be variable width
and stateful.  The entity coding system represents each character by a
single bit combination; it is fixed-width (but not limited to 8 bits)
and stateless.
Note that the SGML declaration describes the entity coding system
not the storage coding system.
.SS "System identifiers"
A system identifier describes a sequence of storage objects,
each optionally associated with a encoding translation.
.I Nsgmls
will attempt to interpret a system identifier
as a keyword followed by a
colon followed by a string, which is interpreted in a keyword-dependent
way.
Keywords are case-insensitive.
The following keywords are recognized:
.TP
.B file
The string is interpreted as a filename.  The system identifier
describes a single storage object that will be read from the named
file.
.TP
.B fd
The string is as a number.  The system identifier describes
a single storage object that will read from the
file descriptor with that number.  For example,
.B fd:0
will read the storage object from standard input.
.TP
.B concat
The string is treated as a list of substrings separated by
.B +
characters.
Each of the substrings is in turn interpreted as a system identifier,
and the sequences of storage objects that each denote are
concatenated.
The
.B concat
system identifier describes the resulting sequence of storage objects.
.TP
.B http
The string together with the
.B http:
prefix is treated as a URL.
This is implemented only under Unix.
.TP
.B utf8
The string is interpreted as a system identifer.  Each storage object
that it describes that is not associated with a encoding translation is
associated with an encoding translation that translates
UTF8 to fixed-width encoding.
Invalid multi-byte sequences are represented by the character 0xFFFD.
This keyword is recognized only in the multi-byte version of
.IR nsgmls .
.TP
.B replace
The string is interpreted as a system identifier.
Numeric character references using
the SGML reference concrete syntax
will be recognized
and replaced
within each storage object identifier occuring
in the system identifier.
.TP
.B ucs2
The string is interpreted as a system identifer.  Each storage object
that it describes that is not associated with a encoding translation
is associated with an encoding translation
that translates UCS2 to a fixed width encoding.
The more significant octet of each character always
precedes the less significant octet irrespective of the system's
native byte-order.
The codes 0xFFFE and 0xFEFF are not treated specially in any way.
This keyword is recognized only in the multi-byte version of
.IR nsgmls .
.TP
.B unicode
The string is interpreted as a system identifer.  Each storage object
that it describes that is not associated with a encoding translation is
associated with the an encoding translation,
which translates the Unicode coding system to a fixed-width encoding.
The Unicode coding system treats each pair of octets
as a character in the system's byte order.
If the first character is the byte order mark character (0xFEFF),
it will be discarded.
(This is necessary to avoid problems with the SGML document entity:
a byte order mark before the SGML declaration would be a syntax error.)
If the first character is the byte order mark character byte-swapped,
it will be discarded and the remaining characters will be byte-swapped.
This keyword is recognized only in the multi-byte version of
.IR nsgmls .
.TP
.B ujis
The string is interpreted as a system identifer.  Each storage object
that it describes that is not associated with a encoding translation is
associated with an encoding translation
where the storage coding system is variable-width (packed) UJIS (EUC),
and the entity coding system represents each character
in the same way as the EUC complete two-byte format.
In the entity coding system
the code of characters
in the G0 set (usually the Japanese version of ISO 646) is unchanged;
The code of characters in the G1 set (usually JIS X 0208-1990) is ORed
with 0x8080; the code of characters in the G2 set (usually half-width
katakana from JIS X 0201-1986) is ORed with 0x0080; the code of
characters in the G3 set (JIS X 0212-1990) is ORed with 0x8000.
This keyword is recognized only in the multi-byte version of
.IR nsgmls .
.TP
.B sjis
The string is interpreted as a system identifer.  Each storage object
that it describes that is not associated with a encoding translation is
associated with an encoding translation
where the storage coding system is Shift JIS
and the entity coding system is the same as with the
.B ujis
encoding translation
(except for characters in the G3 set which are not representable
using Shift JIS.)
This keyword is recognized only in the multi-byte version of
.IR nsgmls .
.TP
.B identity
The string is interpreted as a system identifer.  Each storage object
that it describes that is not associated with a encoding translation is
associated with the identity encoding translation.  The identity coding
system converts bytes to characters by zero-extending each character.
.TP
.B raw
The string is interpreted as a system identifier.
No translation of line-terminators onto RS and RE characters
will be performed for each storage object that it describes.
Error messages referring to these storage objects
will not contain line numbers.
.TP
.B cooked
The string is interpreted as a system identifier.
This undoes the effect of any earlier
.B raw
keyword.
.TP
.B huge
This keyword is intended for use with huge files,
for which the cost of keeping track of line
boundaries (roughly one byte per line) is
too large.
The string is interpreted as a system identifier.
For each storage object that it describes,
.I nsgmls
will not keep track of where line boundaries
occur as it usually does.
Error messages referring to these storage objects
will not contain line numbers.
.LP
If a system identifier does not contain a keyword
or uses a keyword that is not recognized, then
the system identifier will be treated as a filename.
Note that the system identifier
.B file:utf8:doc.sgm
identifies the file named
.B utf8:doc.sgm
but
.B utf8:file:doc.sgm
identifies the file named
.B doc.sgm
using the
.B utf8
coding scheme.
.LP
A relative filename in a system identifier
is interpreted relative to the file in which the system
identifier is specified, if any, and otherwise relative
to the current directory.
This applies both to system identifiers specified in SGML documents,
and to system identifiers specified in catalog entry files.
.LP
If a system identifier does not specify the encoding translation,
the encoding translation of the storage object in which the
system identifier was specified will be used.
.LP
The
.B raw
keyword will be implied for an NDATA entity
and for a system identifier defined in a storage object
that was raw.
This can be overridden using the
.B cooked
keyword.
.SS "System identifier generation"
If a system identifier is not specified,
then the entity manager will attempt to generate one using catalog
entry files in the format defined in the SGML Open Draft Technical
Resolution on Entity Management.  A catalog entry file contains a
sequence of entries in one of the following four forms:
.TP
.BI PUBLIC\  pubid\ sysid
This specifies that
.I sysid
should be used as the system identifier if the public
identifier is
.IR pubid .
.I Sysid
is a system identifier as defined in ISO 8879 and
.I pubid
is a public identifier as defined in ISO 8879.
.TP
.BI ENTITY\  name\ sysid
This specifies that
.I sysid
should be used as the system identifier if the entity is a general
entity whose name is
.IR name .
.TP
.BI ENTITY\ % name\ sysid
This specifies that
.I sysid
should be used as the system identifier if the entity is a parameter
entity whose name is
.IR name .
Note that there is no space between the
.B %
and the
.IR name .
.TP
.BI DOCTYPE\  name\ sysid
This specifies that
.I sysid
should be used as the system identifier if the entity is an
entity declared in a document type declaration whose document type name is
.IR name .
.TP
.BI LINKTYPE\  name\ sysid
This specifies that
.I sysid
should be used as the system identifier if the entity is an
entity declared in a link type declaration whose link type name is
.IR name .
.TP
.B OVERRIDE
This specifies that system identifiers specified in the catalog
should override system identifiers specified in the document.
Normally, if an entity declaration in the document
specifies a system identifier, the catalog is not consulted.
If
.B OVERRIDE
is specified, then the catalog is searched first; the system only uses
the system identifier specified in the document, if no match is found
in the catalog.
.TP
.BI SGMLDECL\  sysid
This specifies that if the document does not contain an SGML declaration,
the SGML declaration in
.I sysid
should be implied.
.LP
The last four forms are extensions to the SGML Open format.
The delimiters can be omitted from the
.I sysid
provided it does not contain any white space.
Comments are allowed between parameters delimited by
.B --
as in SGML.
The environment variable
.B \s-1SGML_CATALOG_FILES\s0
contains a list of catalog entry files.
The list is separated by colons under Unix
and by semi-colons under MSDOS.
These will be searched after any catalog entry files specified
using the
.B \-m
option.
If this environment variable is not set,
then a system dependent list of catalog entry files will be used.
A match in a catalog entry file for a PUBLIC entry will take
precedence over a match in the same file for an ENTITY,
DOCTYPE or LINKTYPE entry.
.br
.ne 18
.SS "System declaration"
The system declaration for
.I nsgmls
is as follows:
.LP
.TS
tab(&);
c1 s1 s1 s1 s1 s1 s1 s1 s
c s s s s s s s s
l l s s s s s s s
l l s s s s s s s
l l s s s s s s s
l l l s s s s s s
c s s s s s s s s
l l l l l l l l l
l l l l l l l l l
l l l l l l l l l
l l s s s s s s s
l l l s s s s s s
l l l s s s s s s
c s s s s s s s s
l l l l l l l l l.
SYSTEM "ISO 8879:1986"
CHARSET
BASESET&"ISO 646-1983//CHARSET
&\h'\w'"'u'International Reference Version (IRV)//ESC 2/5 4/0"
DESCSET&0\0128\00
CAPACITY&PUBLIC&"ISO 8879:1986//CAPACITY Reference//EN"
FEATURES
MINIMIZE&DATATAG&NO&OMITTAG&YES&RANK&YES&SHORTTAG&YES
LINK&SIMPLE&YES 65535&IMPLICIT&YES&EXPLICIT&YES 1
OTHER&CONCUR&NO&SUBDOC&YES 100&FORMAL&YES
SCOPE&DOCUMENT
SYNTAX&PUBLIC&"ISO 8879:1986//SYNTAX Reference//EN"
SYNTAX&PUBLIC&"ISO 8879:1986//SYNTAX Core//EN"
VALIDATE
&GENERAL&YES&MODEL&YES&EXCLUDE&YES&CAPACITY&NO
&NONSGML&YES&SGML&YES&FORMAL&YES
.T&
c s s s s s s s s
l l l l l l l l l.
SDIF
&PACK&NO&UNPACK&NO
.TE
.LP
The limit for the \s-1SUBDOC\s0 parameter is memory dependent.
.LP
Any legal concrete syntax may be used.
.SS "\*S declaration"
The \*S declaration may be omitted,
the following declaration will be implied:
.TS
tab(&);
c1 s1 s1 s1 s1 s1 s1 s1 s
c s s s s s s s s
l l s s s s s s s.
<!SGML "ISO 8879:1986"
CHARSET
BASESET&"ISO 646-1983//CHARSET
&\h'\w'"'u'International Reference Version (IRV)//ESC 2/5 4/0"
DESCSET&\0\00\0\09\0UNUSED
&\0\09\0\02\0\09
&\011\0\02\0UNUSED
&\013\0\01\013
&\014\018\0UNUSED
&\032\095\032
&127\0\01\0UNUSED
.T&
l l l s s s s s s
l l s s s s s s s.
CAPACITY&PUBLIC&"ISO 8879:1986//CAPACITY Reference//EN"
SCOPE&DOCUMENT
SYNTAX
SHUNCHAR&CONTROLS 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17
&18 19 20 21 22 23 24 25 26 27 28 29 30 31 127 255
BASESET&"ISO 646-1983//CHARSET International Reference Version
&\h'\w'"'u'(IRV)//ESC 2/5 4/0"
DESCSET&0\0128\00
.T&
l l l l s s s s s.
FUNCTION&RE&&13
&RS&&10
&SPACE&&32
&TAB&SEPCHAR&9
NAMING&LCNMSTRT&""
&UCNMSTRT&""
&LCNMCHAR&"-."
&UCNMCHAR&"-."
&NAMECASE&GENERAL&YES
&&ENTITY&NO
DELIM&GENERAL&SGMLREF
&SHORTREF&SGMLREF
NAMES&SGMLREF
QUANTITY&SGMLREF
&ATTCNT&99999999
&ATTSPLEN&99999999
&DTEMPLEN&24000
&ENTLVL&99999999
&GRPCNT&99999999
&GRPGTCNT&99999999
&GRPLVL&99999999
&LITLEN&24000
&NAMELEN&99999999
&PILEN&24000
&TAGLEN&99999999
&TAGLVL&99999999
.T&
c s s s s s s s s
l l l s s s s s s.
FEATURES
MINIMIZE&DATATAG&NO
&OMITTAG&YES
&RANK&YES
&SHORTTAG&YES
LINK&SIMPLE&YES\01000
&IMPLICIT&YES
&EXPLICIT&YES\01
OTHER&CONCUR&NO
&SUBDOC&YES\099999999
&FORMAL&YES
.T&
c s s s s s s s s.
APPINFO NONE>
.TE
with the exception that characters 160 through 254 will be assigned to
\s-1DATACHAR\s0.
.LP
A character in a base character set is described either by giving its
number in a universal character set, or by specifying a minimum
literal.  The constraints on the choice of universal character set are
that characters that are significant in the SGML reference concrete
syntax must be in the universal character set and must have the same
number in the universal character set as in ISO 646 and that each
character in the character set must be represented by exactly one
number; that character numbers in the range 0 to 31 and 127 to 159 are
control characters (for the purpose of enforcing SHUNCHAR CONTROLS).
It is recommended that ISO 10646 (Unicode) be used as the universal
character set, except in environments where the normal document
character sets are large character set which cannot be compactly
described in terms of ISO 10646.
The public identifier of a base character set can be associated
with an entity that describes it by using a
.B PUBLIC
entry in the catalog entry file.
The entity must be a fragment
of an SGML declaration
consisting of the
the portion of a character set description,
following the DESCSET keyword
that is, it must be a sequence of character descriptions,
where each character description specifies a described character
number, the number of characters and
either a character number in the universal character set, a minimum literal
or the keyword
.BR UNUSED .
Character numbers in the universal character set can be as big as
99999999.
.LP
In addition 
.I nsgmls
has built in knowledge of a few character sets.
These are identified using the designating sequence in the
public identifier.  The following designating sequences are
recognized:
.TS
tab(&);
c c c c c
c c c c ^
c c c c ^
l n n n l.
Designating&ISO&Minimum&Number&Description
Escape&Registration&Character&of&
Sequence&Number&Number&Characters&
_
ESC 2/5 4/0&-&0&128&full set of ISO 646 IRV
ESC 2/8 4/0&2&0&128&G0 set of ISO 646 IRV
ESC 2/8 4/2&6&0&128&G0 set of ASCII
ESC 2/1 4/0&1&0&32&C0 set of ISO 646
.TE
.LP
The graphic character sets do not strictly include
C0 and C1 control character sets.
For convenience,
.I nsgmls
augments the graphic character sets with the appropriate
control character sets.
.LP
It is not necessary for every character set used in the SGML
declaration to be known to
.I nsgmls
provided that characters in the document character set that are
significant both in the reference concrete syntax and in the described
concrete syntax are described using known base character sets and that
characters that are significant in the described concrete syntax are
described using the same base character sets or the same minimum
literals in both the document character set description and the syntax
reference character set description.
.LP
The public identifier for a public concrete syntax can be associated
with an entity that describes using a
.B PUBLIC
entry in the catalog entry file.
The entity must be a fragment of an SGML declaration
consisting of a concrete syntax description
starting with the
.B SHUNCHAR
keyword
as in an SGML declaration.
The entity can also make use of the following extensions:
.IP
An
.I added\ function
can be expressed as a parameter literal
instead of a name.
.IP
The replacement for a reference reserved name
can be expressed as a parameter literal instead of a name.
.IP
The
.BR LCNMSTRT ,
.BR UCNMSTRT ,
.B LCNMCHAR
and
.B UCNMCHAR
keywords may each be followed by more than one parameter literal.  A
sequence of parameter literals has the same meaning as a single
parameter literal whose content is the concatenation of the content of
each of the literals in the sequence.  This extension is useful
because of the restriction on the length of a parameter literal in the
SGML declaration to 240 characters.
.IP
The total number of characters specified for
.B UCNMCHAR
or
.B UCNMSTRT
may exceed the total number of characters specified for
.B LCNMCHAR
or
.B LCNMSTRT
respectively.
Each character in
.B UCNMCHAR
or
.B UCNMSTRT
which does not have a corresponding character in the same position in
.B LCNMCHAR
or
.B LCNMSTRT
is simply assigned to UCNMCHAR or UCNMSTRT
without making it the upper-case form of any character.
.IP
A parameter following any of
.BR LCNMSTRT ,
.BR UCNMSTRT ,
.B LCNMCHAR
and
.B UCNMCHAR
keywords
may be followed by
the name token
.B .\|.\|.
and another parameter literal.
This has the same meaning as the two parameter literals
with a parameter literal in between
containing in order each character whose number
is greater than the number of the last character in
the first parameter literal and less than the
number of the first character in the second
parameter literal.
A parameter literal must contain at least one character for each
.B .\|.\|.
to which it is adjacent.
.IP
A number may be used as a parameter following the
.BR LCNMSTRT ,
.BR UCNMSTRT ,
.B LCNMCHAR
and
.B UCNMCHAR
keywords or as a delimiter in the
.B DELIM
section with the same meaning as a parameter literal
containing just a numeric character reference with that number.
.IP
The parameters following the
.BR LCNMSTRT ,
.BR UCNMSTRT ,
.B LCNMCHAR
and
.B UCNMCHAR
keywords may be omitted.
This has the same meaning as specifying
an empty parameter literal.
.IP
Within the specification of the short reference delimiters,
a parameter literal containing exactly one character
may be followed by the name token
.B .\|.\|.
and another parameter literal containing exactly one character.
This has the same meaning as a sequence of parameter literals
one for each character number that is greater than or equal
to the number of the character in the first parameter literal
and less than or equal to the number of the character in the
second parameter literal.
.LP
The public identifier for a public capacity set can be associated
with an entity that describes using a
.B PUBLIC
entry in the catalog entry file.
The entity must be a fragment of an SGML declaration
consisting of a sequence of capacity names and numbers.
.SS "Output format"
The output is a series of lines.
Lines can be arbitrarily long.
Each line consists of an initial command character
and one or more arguments.
Arguments are separated by a single space,
but when a command takes a fixed number of arguments
the last argument can contain spaces.
There is no space between the command character and the first argument.
Arguments can contain the following escape sequences.
.TP
.B \e\e
A
.BR \e.
.TP
.B \en
A record end character.
.TP
.B \e|
Internal \s-1SDATA\s0 entities are bracketed by these.
.TP
.BI \e nnn
The character whose code is
.I nnn
octal.
.LP
A record start character will be represented by
.BR \e012 .
Most applications will need to ignore
.B \e012
and translate
.B \en
into newline.
.LP
The possible command characters and arguments are as follows:
.TP
.BI ( gi
The start of an element whose generic identifier is
.IR gi .
Any attributes for this element
will have been specified with
.B A
commands.
.TP
.BI ) gi
The end an element whose generic identifier is
.IR gi .
.TP
.BI \- data
Data.
.TP
.BI & name
A reference to an external data entity
.IR name ;
.I name
will have been defined using an
.B E
command.
.TP
.BI ? pi
A processing instruction with data
.IR pi .
.TP
.BI A name\ val
The next element to start has an attribute
.I name
with value
.I val
which takes one of the following forms:
.RS
.TP
.B IMPLIED
The value of the attribute is implied.
.TP
.BI CDATA\  data
The attribute is character data.
This is used for attributes whose declared value is
.BR \s-1CDATA\s0 .
.TP
.BI NOTATION\  nname
The attribute is a notation name;
.I nname
will have been defined using a
.B N
command.
This is used for attributes whose declared value is
.BR \s-1NOTATION\s0 .
.TP
.BI ENTITY\  name\|.\|.\|.
The attribute is a list of general entity names.
Each entity name will have been defined using an
.BR I ,
.B E
or
.B S
command.
This is used for attributes whose declared value is
.B \s-1ENTITY\s0
or
.BR \s-1ENTITIES\s0 .
.TP
.BI TOKEN\  token\|.\|.\|.
The attribute is a list of tokens.
This is used for attributes whose declared value is anything else.
.RE
.TP
.BI D ename\ name\ val
This is the same as the
.B A
command, except that it specifies a data attribute for an
external entity named
.IR ename .
Any
.B D
commands will come after the
.B E
command that defines the entity to which they apply, but
before any
.B &
or
.B A
commands that reference the entity.
.TP
.BI a type\ name\ val
The next element to start has a link attribute with link type
.IR type ,
name
.IR name ,
and value
.IR val ,
which takes the same form as with the
.B A
command.
.TP
.BI N nname
.IR nname.
Define a notation.
This command will be preceded by a
.B p
command if the notation was declared with a public identifier,
and by a
.B s
command if the notation was declared with a system identifier.
A notation will only be defined if it is to be referenced
in an
.B E
command or in an
.B A
command for an attribute with a declared value of
.BR \s-1NOTATION\s0 .
.TP
.BI E ename\ typ\ nname
Define an external data entity named
.I ename
with type
.I typ
.RB ( \s-1CDATA\s0 ,
.B \s-1NDATA\s0
or
.BR \s-1SDATA\s0 )
and notation
.IR not.
This command will be preceded by one or more
.B f
commands giving the filenames generated by the entity manager from the system
and public identifiers,
by a
.B p
command if a public identifier was declared for the entity,
and by a
.B s
command if a system identifier was declared for the entity.
.I not
will have been defined using a
.B N
command.
Data attributes may be specified for the entity using
.B D
commands.
An external data entity will only be defined if it is to be referenced in a
.B &
command or in an
.B A
command for an attribute whose declared value is
.B \s-1ENTITY\s0
or
.BR \s-1ENTITIES\s0 .
.TP
.BI I ename\ typ\ text
Define an internal data entity named
.I ename
with type
.I typ
.RB ( \s-1CDATA\s0
or
.BR \s-1SDATA\s0 )
and entity text
.IR text .
An internal data entity will only be defined if it is referenced in an
.B A
command for an attribute whose declared value is
.B \s-1ENTITY\s0
or
.BR \s-1ENTITIES\s0 .
.TP
.BI S ename
Define a subdocument entity named
.IR ename .
This command will be preceded by one or more
.B f
commands giving the filenames generated by the entity manager from the system
and public identifiers,
by a
.B p
command if a public identifier was declared for the entity,
and by a
.B s
command if a system identifier was declared for the entity.
A subdocument entity will only be defined if it is referenced
in a
.B {
command
or in an
.B A
command for an attribute whose declared value is
.B \s-1ENTITY\s0
or
.BR \s-1ENTITIES\s0 .
.TP
.BI s sysid
This command applies to the next
.BR E ,
.B S
or
.B N
command and specifies the associated system identifier.
.TP
.BI p pubid
This command applies to the next
.BR E ,
.B S
or
.B N
command and specifies the associated public identifier.
.TP
.BI f filename
This command applies to the next
.B E
or
.B S
command and specifies the effective system identifier.
The effective system identifier is the system identifier
generated by the system from the specified external identifier
and other information about the entity.
.TP
.BI { ename
The start of the \*S subdocument entity
.IR ename ;
.I ename
will have been defined using a
.B S
command.
.TP
.BI } ename
The end of the \*S subdocument entity
.IR ename .
.TP
.BI L lineno\ file
.TQ
.BI L lineno
Set the current line number and filename.
The
.I filename
argument will be omitted if only the line number has changed.
This will be output only if the
.B \-l
option has been given.
.TP
.BI # text
An \s-1APPINFO\s0 parameter of
.I text
was specified in the \*S declaration.
This is not strictly part of the ESIS, but a structure-controlled
application is permitted to act on it.
No
.B #
command will be output if
.B \s-1APPINFO\s0\ \s-1NONE\s0
was specified.
A
.B #
command will occur at most once,
and may be preceded only by a single
.B L
command.
.TP
.B C
This command indicates that the document was a conforming \*S document.
If this command is output, it will be the last command.
An \*S document is not conforming if it references a subdocument entity
that is not conforming.
.SH ENVIRONMENT
.TP
.SM
.B NSGMLS_CODE
If this is set to the name of a encoding translation, then that
encoding translation will be used as the default encoding translation
for everything (including file input, file output, message output,
filenames and command line arguments).  Otherwise the
.B identity
encoding translation will be used.
Setting this to
.B ucs2
or
.B unicode
is unlikely to give reasonable results.
.SH "SEE ALSO"
The \*S Handbook, Charles F. Goldfarb
.br
\s-1ISO\s0 8879 (Standard Generalized Markup Language),
International Organization for Standardization
.SH BUGS
.LP
Not all ESIS information for LINK is reported.
.SH AUTHOR
.LP
James Clark (jjc@jclark.com).
